---
layout: doc
title: How to create a Kali Linux VM
permalink: /doc/pentesting/kali/
redirect_from:
- /doc/kali/
---

How to create a Kali Linux VM
===============================
Warnings
--------------
* The installation scripts and provided tools may have bugs, be vulnerable to Man in the Middle (MitM) attacks or other vulnerabilities.
* Adding additional repositories or tools for installing software extends your trust to those tool providers.
* Please keep in mind that using such a VM or VM's based on the template for security and privacy critical tasks is not recommended.
* Kali Linux distribution is a rolling distribution based constantly on Debian testing release, so it always will have newer software base than available in Qubes OS debian template. Keep in mind that it may result in problems (especially in regard to package dependency) not covered by this tutorial.

From the official ISO file <a name="hvm4_0"/>
==================================================
Only use this method if you want to have the full Kali GUI (desktop, fancy menus, ...), it come at the cost of much greater resources consumption.

1. Download the Kali installation DVD
2. Create a new HVM
3. Start the HVM with attached CD/DVD
```shell_session
$ qvm-start <hvm-name> --cdrom <vm-name>:/home/user/Downloads/<iso-name>.iso
```

From a Debian template  <a name="templatevm-from-debian4_0"/>
================================================================
This is the recommanded method.
Easier to maintain and less demanding on resources, but you won't have the full Kali GUI.

If you need to install custom kernel modules (wifi drivers, ...) you need use the kernel provided by Kali instead of the kernel provided by Qubes, see [Managing VM Kernel](/doc/managing-vm-kernel/)

The steps can be summarised as:

1. Install Qubes stable Debian template
2. Upgrade the template to Debian testing release
3. Add the Kali repository
4. Update the template

Get Kali Linux GPG key
-----------------------
**CAUTION:** Before proceeding, please carefully read [On Digital Signatures and Key Verification][qubes-verifying-signatures].
This website cannot guarantee that any PGP key you download from the Internet is authentic.
Always obtain a trusted key fingerprint via other channels, and always check any key you download against your trusted copy of the fingerprint.

This step is required since by (security) default a TemplateVM do not have a
direct Internet connectivity. Users understanding the risks of enabling such
access can change this configuration in firewall settings for the TemplateVM.

1. Retrive the Kali Linux GPG key using a DisposableVM.

```shell_session
$ gpg --keyserver hkp://keys.gnupg.net --recv-key 44C6513A8E4FB3D30875F758ED444FF07D8D0BF6
$ gpg --list-keys --with-fingerprint 44C6513A8E4FB3D30875F758ED444FF07D8D0BF6 
$ gpg --export --armor 44C6513A8E4FB3D30875F758ED444FF07D8D0BF6 > kali-key.asc
```

2. **DO NOT TURN OFF** the DisposableVM, the `kali-key.asc` file will be copied to
   the Kali Linux template in a further step.

3. Make sure the key is the authentic Kali key.
   See the [Kali website] for further advice and instructions on verification.

Create a Kali Linux (rolling) template
----------------------------------------
These instructions will show you how to upgrade a Debian TemplateVM to Kali Linux.

1. (Optional) Check for latest Debian stable template and install it (if not already done)

```shell_session
$ sudo qubes-dom0-update --action="search all" qubes-template-debian
$ sudo qubes-dom0-update <latest Debian template>
```

2. Start your latest Debian template

```shell_session
$ qvm-start debian-<X>
$ qvm-run -a debian-<X> gnome-terminal
```

3. Update it

4. And then close it

```shell_session
$ qvm-shutdown debian-<X>
```

5. Clone `debian-X` template

```shell_session
$ qvm-clone debian-<X> kali-rolling
```

6. Check the name of currently used repository in `/etc/apt/sources.list` and current testing [Debian release][Debian-releases]. Update repository list accordingly

```shell_session
# sed -i 's/<current stable>/<current testing>/g' /etc/apt/sources.list
# sed -i 's/<current stable>/<current testing>/g' /etc/apt/sources.list.d/qubes-r<X>.list
```

e.g. in this example we update `buster` stable repository to `bullseye` testing repository

```shell_session
# sed -i 's/buster/bullseye/g' /etc/apt/sources.list
# sed -i 's/buster/bullseye/g' /etc/apt/sources.list.d/qubes-r<X>.list
```
        
For installation based on Debian 10 stable, please note that the security repository of Debian testing has [recently been renamed][Debian-security-naming-convention] from `<current testing>/update` to `<current-testing>-security`. To account for that change, execute the following command.

```shell_session
# sed -i 's/bullseye\/updates/bullseye-security/g' /etc/apt/sources.list
```

5. Update the template

**Note:** During execution of the update, read carefully list of packages to be removed. If it contains `qubes-*` packages, terminate operation and try to resolve `qubes-*` packages missing dependencies first.

6. Copy the Kali GPG key from the DisposableVM to the new template:

```shell_session
$ qvm-copy kali-key.asc
```

   The DisposableVM can now be turned off.

7. Add the Kali GPG key to the list of keys trusted to authenticate packages:

```shell_session
# cat /home/user/QubesIncoming/dispXXX/kali-key.asc | apt-key add -
```

   This command should return `OK` on a line by itself.

8. Add the Kali repository

```shell_session
# cat <<EOF > /etc/apt/sources.list.d/kali.list
# Kali Linux repository
deb https://http.kali.org/kali kali-rolling main non-free contrib
EOF
```

9. Update the template 

10. Ensure a terminal can be opened in the new template.

```shell_session
$ qvm-run -a kali-rolling gnome-terminal
```

Install the Kali tools
------------------------------
At this point you should have a working template and you can install the tools you need.
Keep in mind that the tools you will install can easily take more than 10GB, [so you will need to **grow** the size of the VM][qubes-resize-disk-image]

Alternative Options to Kali Linux
===================================
* [PenTester Framework][PTF], with [PTF Qubes OS guide][qubes-ptf]
* BlackArch Linux, with [BA Qubes OS guide][qubes-blackarch]
* more on the [Penetration Testing page][qubes-pentesting]
 

Notes
=============
Thanks to the people in [the discussion thread](https://github.com/QubesOS/qubes-issues/issues/1981).

[qubes-verifying-signatures]: /security/verifying-signatures/
[qubes-pentesting]: /doc/pentesting/
[qubes-blackarch]: /doc/pentesting/blackarch/
[qubes-ptf]: /doc/pentesting/ptf/
[qubes-template-debian-install]: /doc/templates/debian/#install
[qubes-resize-disk-image]: /doc/resize-disk-image/

[kali]: https://www.kali.org/
[kali-vbox]: https://www.offensive-security.com/kali-linux-vmware-virtualbox-image-download/
[kali website]: https://docs.kali.org/introduction/download-official-kali-linux-images

[PTF]: https://www.trustedsec.com/may-2015/new-tool-the-pentesters-framework-ptf-released/

[katoolin]: https://github.com/LionSec/katoolin
[katoolin-howto]: http://www.tecmint.com/install-kali-linux-tools-using-katoolin-on-ubuntu-debian/

[Debian-releases]: https://www.debian.org/releases/

[Debian-security-naming-convention]: https://www.mail-archive.com/debian-security@lists.debian.org/msg41223.html

